# App for practicing Japanese

## Setup

### Linux

1. Install Python 3 and pip.
2. Install mpv for audio playback:
   ```bash
   sudo apt-get install mpv
   ```
3. Install the app via pip

## Known issues:

N/A

## Testing solution:

N/A